==> kubernetes-client-4.7.1-sources.jar: io/fabric8/kubernetes/client/handlers/EndpointSliceHandler.java <==

/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

                        

package io.fabric8.kubernetes.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.kubernetes.client.dsl.internal.EndpointSliceOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.discovery.EndpointSlice;
import io.fabric8.kubernetes.api.model.discovery.EndpointSliceBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class EndpointSliceHandler implements ResourceHandler<EndpointSlice, EndpointSliceBuilder> {

  @Override
  public String getKind() {
    return EndpointSlice.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "discovery/v1alpha1";
      }

  @Override
  public EndpointSlice create(OkHttpClient client, Config config, String namespace, EndpointSlice item) {
    return new EndpointSliceOperationsImpl(client, config).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public EndpointSlice replace(OkHttpClient client, Config config, String namespace, EndpointSlice item) {
    return new EndpointSliceOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public EndpointSlice reload(OkHttpClient client, Config config, String namespace, EndpointSlice item) {
    return new EndpointSliceOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public EndpointSliceBuilder edit(EndpointSlice item) {
    return new EndpointSliceBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, Boolean cascading, EndpointSlice item) {
    return new EndpointSliceOperationsImpl(client, config, namespace).withItem(item).cascading(cascading).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, EndpointSlice item, Watcher<EndpointSlice> watcher) {
    return new EndpointSliceOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, EndpointSlice item, String resourceVersion, Watcher<EndpointSlice> watcher) {
    return new EndpointSliceOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public EndpointSlice waitUntilReady(OkHttpClient client, Config config, String namespace, EndpointSlice item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new EndpointSliceOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public EndpointSlice waitUntilCondition(OkHttpClient client, Config config, String namespace, EndpointSlice item, Predicate<EndpointSlice> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new EndpointSliceOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> kubernetes-client-4.9.0-sources.jar: io/fabric8/kubernetes/client/handlers/EndpointSliceHandler.java <==

/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

                        

package io.fabric8.kubernetes.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.kubernetes.client.dsl.internal.EndpointSliceOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.discovery.EndpointSlice;
import io.fabric8.kubernetes.api.model.discovery.EndpointSliceBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class EndpointSliceHandler implements ResourceHandler<EndpointSlice, EndpointSliceBuilder> {

  @Override
  public String getKind() {
    return EndpointSlice.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "discovery/v1beta1";
      }

  @Override
  public EndpointSlice create(OkHttpClient client, Config config, String namespace, EndpointSlice item) {
    return new EndpointSliceOperationsImpl(client, config).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public EndpointSlice replace(OkHttpClient client, Config config, String namespace, EndpointSlice item) {
    return new EndpointSliceOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public EndpointSlice reload(OkHttpClient client, Config config, String namespace, EndpointSlice item) {
    return new EndpointSliceOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public EndpointSliceBuilder edit(EndpointSlice item) {
    return new EndpointSliceBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, Boolean cascading, EndpointSlice item) {
    return new EndpointSliceOperationsImpl(client, config, namespace).withItem(item).cascading(cascading).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, EndpointSlice item, Watcher<EndpointSlice> watcher) {
    return new EndpointSliceOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, EndpointSlice item, String resourceVersion, Watcher<EndpointSlice> watcher) {
    return new EndpointSliceOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public EndpointSlice waitUntilReady(OkHttpClient client, Config config, String namespace, EndpointSlice item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new EndpointSliceOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public EndpointSlice waitUntilCondition(OkHttpClient client, Config config, String namespace, EndpointSlice item, Predicate<EndpointSlice> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new EndpointSliceOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
